@@ -14,7 +14,7 @@ serve_path = str(Path(__file__).with_name("serve").resolve())
 
 serve = {"__trame_vtklocal": serve_path}
 scripts = ["__trame_vtklocal/js/trame_vtklocal.umd.js"]
-styles = ["__trame_vtklocal/js/style.css"]
+styles = ["__trame_vtklocal/js/trame_vtklocal.css"]
 vue_use = ["trame_vtklocal"]
 
 # -----------------------------------------------------------------------------
@@ -30,5 +30,7 @@ def get_helper(server):
 
 def setup(trame_server, **kwargs):
     global HELPERS_PER_SERVER
-    HELPERS_PER_SERVER[trame_server.name] = ObjectManagerHelper(trame_server)
-    trame_server.enable_module(register_wasm(serve_path))
+    HELPERS_PER_SERVER[trame_server.name] = ObjectManagerHelper(
+        trame_server, addon_serdes_registrars=kwargs.pop("addon_serdes_registrars", [])
+    )
+    trame_server.enable_module(register_wasm(serve_path, **kwargs))
